@@ -420,7 +420,7 @@ def numba_compute_fees(arr, d):
 
 
 
-def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = True):
+def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = False):
     dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
 
     start_time_stub = start_time.strftime('%d_%b_%Y')
@@ -721,7 +721,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
         x = wh[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
                 'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
-                'valuation', 'fut_transfer_usdt_amount', 'wallet_balance',
+                'valuation', 'fut_transfer_usdt_amount', 'wallet_balance','pnl',
                 'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
                 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
                 'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
@@ -733,7 +733,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
                      'open_eth_cc', 'open_eth_exchange',
                      'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
                      'open_btc_cc', 'open_btc_exchange',
-                     'wallet_amount_usd', 'transfers_usd', 'wallet_binance_balance',
+                     'wallet_amount_usd', 'transfers_usd', 'wallet_binance_balance','pnl',
                      'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
                      'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
                      'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
